==> youqian-api-1.5.12-sources.jar: com/youqian/api/remoteservice/RemoteCustomerService.java <==
package com.youqian.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import com.youqian.api.dto.customer.CustomerDto;
import com.youqian.api.params.customer.CustomerAddParam;
import com.youqian.api.params.customer.CustomerKickOffParam;
import com.youqian.api.params.customer.CustomerParam;
import com.youqian.api.params.customer.CustomerLiveAddParam;
import com.youqian.api.params.customer.SelectCustomerParam;
import com.youqian.api.request.CreateCustomerIntentRequest;
import com.youqian.api.request.Customer;
import com.youqian.auth.api.exception.BizException;

import java.util.Collection;
import java.util.List;

/**
 * @author tengtuox
 * @date 2020/4/21
 * @description
 */
@AdvancedFeignClient
public interface RemoteCustomerService {

    /**
     * 批量查询客户
     *
     * @param customerIds 客户ID
     * @return List<CustomerDto>
     */
    List<CustomerDto> batchGet(Collection<Long> customerIds) throws BizException;

    /**
     * 判定是否黑名单
     *
     * @param selectCustomerParam 查询参数
     */
    CustomerDto getInfo(SelectCustomerParam selectCustomerParam) throws BizException;

    /**
     * 展示客户列表
     */
    List<CustomerDto> customerInfoList(CustomerParam customerParam) throws BizException;

    /**
     * 展示客户列表
     */
    Integer countCustomerInfo(CustomerParam customerParam) throws BizException;

    /**
     * 新增客户
     * @param customerAddParam 客户操作参数
     */
    CustomerDto addCustomer(CustomerAddParam customerAddParam);

    /**
     * 查询商户下的用户信息
     */
    List<CustomerDto> getCustomerInfo(Long merchantId,List<Long> userIds);

    /**
     * 查询商户下的员工
     */
    List<CustomerDto> getCustomerByMerchantId(Long merchantId);


    /**
     * 批量新增客户
     * @return
     */
    Boolean batchAddCustomer(Long merchantId,List<Customer> customers);
    /**
    * 直播申请新增客户
     * @param customerLiveAddParam 客户操作参数
     */
    CustomerDto addLiveCustomer(CustomerLiveAddParam customerLiveAddParam);

    /**
     * 定时任务：客户数据统计
     */
    void customerStatisticalTime();

    /**
     * 定时任务:统计互动分
     */
    void customerScore();

    /**
     * 客户拉黑
     */
    void customerKickOff(CustomerKickOffParam customerKickOffParam);

    /**
     * 查询商户列表
     */
    List<CustomerDto> selectByMerchantIds(List<Long> merchantIds);

    /**
     * 创建意向客户
     */
    Boolean createCustomerIntent(CreateCustomerIntentRequest request);
}

==> youqian-api-1.5.33-sources.jar: com/youqian/api/remoteservice/RemoteCustomerService.java <==
package com.youqian.api.remoteservice;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import com.youqian.api.dto.customer.CustomerDto;
import com.youqian.api.dto.customer.CustomerStatisticalDto;
import com.youqian.api.params.customer.CustomerAddParam;
import com.youqian.api.params.customer.CustomerKickOffParam;
import com.youqian.api.params.customer.CustomerParam;
import com.youqian.api.params.customer.CustomerLiveAddParam;
import com.youqian.api.params.customer.SelectCustomerParam;
import com.youqian.api.request.CreateCustomerIntentRequest;
import com.youqian.api.request.Customer;
import com.youqian.auth.api.exception.BizException;

import java.util.Collection;
import java.util.List;

/**
 * @author tengtuox
 * @date 2020/4/21
 * @description
 */
@AdvancedFeignClient
public interface RemoteCustomerService {

    /**
     * 批量查询客户
     *
     * @param customerIds 客户ID
     * @return List<CustomerDto>
     */
    List<CustomerDto> batchGet(Collection<Long> customerIds) throws BizException;

    /**
     * 判定是否黑名单
     *
     * @param selectCustomerParam 查询参数
     */
    CustomerDto getInfo(SelectCustomerParam selectCustomerParam) throws BizException;

    /**
     * 展示客户列表
     */
    List<CustomerDto> customerInfoList(CustomerParam customerParam) throws BizException;

    /**
     * 展示客户列表
     */
    Integer countCustomerInfo(CustomerParam customerParam) throws BizException;

    /**
     * 新增客户
     * @param customerAddParam 客户操作参数
     */
    CustomerDto addCustomer(CustomerAddParam customerAddParam);

    /**
     * 查询商户下的用户信息
     */
    List<CustomerDto> getCustomerInfo(Long merchantId,List<Long> userIds);

    /**
     * 查询商户下的员工
     */
    List<CustomerDto> getCustomerByMerchantId(Long merchantId);


    /**
     * 批量新增客户
     * @return
     */
    Boolean batchAddCustomer(Long merchantId,List<Customer> customers);
    /**
    * 直播申请新增客户
     * @param customerLiveAddParam 客户操作参数
     */
    CustomerDto addLiveCustomer(CustomerLiveAddParam customerLiveAddParam);

    /**
     * 定时任务：客户数据统计
     */
    void customerStatisticalTime();

    /**
     * 定时任务:统计互动分
     */
    void customerScore();

    /**
     * 客户拉黑
     */
    void customerKickOff(CustomerKickOffParam customerKickOffParam);

    /**
     * 查询商户列表
     */
    List<CustomerDto> selectByMerchantIds(List<Long> merchantIds);

    /**
     * 查询商户的客户
     */
    List<CustomerDto> selectByMerchantId(Long merchantId);

    /**
     * 创建意向客户
     */
    Boolean createCustomerIntent(CreateCustomerIntentRequest request);

    /**
     * 查询直播间意向客户总数
     * @param liveRoomId 直播间ID
     * @return 意向客户数
     */
    Integer selectIntentByLiveRoom(Long liveRoomId);

    /**
     * 客户统计
     */
    CustomerStatisticalDto selectByCustomerType(Long customerId,Byte type);

    /**
     * 客户统计操作
     * @param c 客户信息
     * @param type 0-更新 1-插入
     * @return
     */
    boolean customerStatisticalOperator(CustomerStatisticalDto c,Integer type);
}
